import { Inject, MiddlewareConsumer, Module, NestModule } from '@nestjs/common';
import { RequestHandler } from 'express';
import { CSRFMiddleware } from 'src/middleware/csrf.middleware';
import { FlashMiddleware } from 'src/middleware/flash.middleware';
import { UserMiddleware } from 'src/middleware/user.middleware';
import { ValidateCSRFMiddleware } from 'src/middleware/validate-csrf.middleware';
import { AuditModule } from 'src/modules/objects/audit/audit.module';
import { UserModule } from 'src/modules/objects/user/user.module';
import { SessionModule } from '../session/session.module';
import { RegisterController } from './register.controller';

@Module({
  imports: [UserModule, AuditModule, SessionModule],
  controllers: [RegisterController],
})
export class RegisterModule implements NestModule {
  constructor(@Inject('SESSION') private _session: RequestHandler) {}

  configure(consumer: MiddlewareConsumer) {
    consumer
      .apply(
        this._session,
        CSRFMiddleware,
        FlashMiddleware,
        UserMiddleware,
        ValidateCSRFMiddleware,
      )
      .forRoutes(RegisterController);
  }
}
